//
//  FlybitsSmartRewardsSDK.h
//  FlybitsSmartRewardsSDK
//
//  Created by Michael on 2019-01-02.
//  Copyright © 2019 Flybits. All rights reserved.
//

#import <UIKit/UIKit.h>

//! Project version number for FlybitsSmartRewardsSDK.
FOUNDATION_EXPORT double FlybitsSmartRewardsSDKVersionNumber;

//! Project version string for FlybitsSmartRewardsSDK.
FOUNDATION_EXPORT const unsigned char FlybitsSmartRewardsSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsSmartRewardsSDK/PublicHeader.h>
